@@ -10,8 +10,6 @@ from __future__ import absolute_import
 
 import os
 
-from collections import Callable
-
 from celery.local import Proxy
 from celery import _state
 from celery._state import (
@@ -148,6 +146,6 @@ def shared_task(*args, **kwargs):
             return Proxy(task_by_cons)
         return __inner
 
-    if len(args) == 1 and isinstance(args[0], Callable):
+    if len(args) == 1 and callable(args[0]):
         return create_shared_task(**kwargs)(args[0])
     return create_shared_task(*args, **kwargs)
