@@ -177,7 +177,7 @@ def filter_hidden_settings(conf):
             return filter_hidden_settings(value)
         if isinstance(value, string_t) and HIDDEN_SETTINGS.search(key):
             return mask
-        if 'BROKER_URL' in key.upper():
+        if isinstance(key, string_t) and 'BROKER_URL' in key.upper():
             from kombu import Connection
             return Connection(value).as_uri(mask=mask)
         return value
@@ -246,6 +246,8 @@ def find_app(app, symbol_by_name=symbol_by_name, imp=import_from_cwd):
                     if isinstance(suspect, Celery):
                         return suspect
                 raise
+            else:
+                return found
         else:
             return found
     return sym
