@@ -9,19 +9,24 @@
 
 """
 from __future__ import absolute_import
-from __future__ import with_statement
 
 import socket
-import threading
-import time
+
+from collections import deque
+from operator import itemgetter
 
 from kombu import Exchange, Queue, Producer, Consumer
 
 from celery import states
 from celery.exceptions import TimeoutError
+from celery.five import range, monotonic
+from celery.utils.functional import dictfilter
 from celery.utils.log import get_logger
+from celery.utils.timeutils import maybe_s_to_ms
 
-from .base import BaseDictBackend
+from .base import BaseBackend
+
+__all__ = ['BacklogLimitExceeded', 'AMQPBackend']
 
 logger = get_logger(__name__)
 
@@ -41,7 +46,7 @@ class NoCacheQueue(Queue):
     can_cache_declaration = False
 
 
-class AMQPBackend(BaseDictBackend):
+class AMQPBackend(BaseBackend):
     """Publishes results by sending messages."""
     Exchange = Exchange
     Queue = NoCacheQueue
@@ -60,43 +65,37 @@ class AMQPBackend(BaseDictBackend):
         'interval_max': 1,
     }
 
-    def __init__(self, connection=None, exchange=None, exchange_type=None,
-                 persistent=None, serializer=None, auto_delete=True,
-                 **kwargs):
-        super(AMQPBackend, self).__init__(**kwargs)
+    def __init__(self, app, connection=None, exchange=None, exchange_type=None,
+                 persistent=None, serializer=None, auto_delete=True, **kwargs):
+        super(AMQPBackend, self).__init__(app, **kwargs)
         conf = self.app.conf
         self._connection = connection
-        self.queue_arguments = {}
-        self.persistent = (conf.CELERY_RESULT_PERSISTENT if persistent is None
-                           else persistent)
-        delivery_mode = persistent and 'persistent' or 'transient'
+        self.persistent = self.prepare_persistent(persistent)
+        self.delivery_mode = 2 if self.persistent else 1
         exchange = exchange or conf.CELERY_RESULT_EXCHANGE
         exchange_type = exchange_type or conf.CELERY_RESULT_EXCHANGE_TYPE
-        self.exchange = self.Exchange(name=exchange,
-                                      type=exchange_type,
-                                      delivery_mode=delivery_mode,
-                                      durable=self.persistent,
-                                      auto_delete=False)
+        self.exchange = self._create_exchange(
+            exchange, exchange_type, self.delivery_mode,
+        )
         self.serializer = serializer or conf.CELERY_RESULT_SERIALIZER
         self.auto_delete = auto_delete
 
-        # AMQP_TASK_RESULT_EXPIRES setting is deprecated and will be
-        # removed in version 4.0.
-        dexpires = conf.CELERY_AMQP_TASK_RESULT_EXPIRES
-
         self.expires = None
-        if 'expires' in kwargs:
-            if kwargs['expires'] is not None:
-                self.expires = self.prepare_expires(kwargs['expires'])
-        else:
-            self.expires = self.prepare_expires(dexpires)
+        if 'expires' not in kwargs or kwargs['expires'] is not None:
+            self.expires = self.prepare_expires(kwargs.get('expires'))
+        self.queue_arguments = dictfilter({
+            'x-expires': maybe_s_to_ms(self.expires),
+        })
 
-        if self.expires:
-            self.queue_arguments['x-expires'] = int(self.expires * 1000)
-        self.mutex = threading.Lock()
+    def _create_exchange(self, name, type='direct', delivery_mode=2):
+        return self.Exchange(name=name,
+                             type=type,
+                             delivery_mode=delivery_mode,
+                             durable=self.persistent,
+                             auto_delete=False)
 
     def _create_binding(self, task_id):
-        name = task_id.replace('-', '')
+        name = self.rkey(task_id)
         return self.Queue(name=name,
                           exchange=self.exchange,
                           routing_key=name,
@@ -107,38 +106,46 @@ class AMQPBackend(BaseDictBackend):
     def revive(self, channel):
         pass
 
-    def _republish(self, channel, task_id, body, content_type,
-                   content_encoding):
-        return Producer(channel).publish(
-            body,
-            exchange=self.exchange,
-            routing_key=task_id.replace('-', ''),
-            serializer=self.serializer,
-            content_type=content_type,
-            content_encoding=content_encoding,
-            retry=True, retry_policy=self.retry_policy,
-            declare=[self._create_binding(task_id)],
-        )
+    def rkey(self, task_id):
+        return task_id.replace('-', '')
 
-    def _store_result(self, task_id, result, status, traceback=None):
+    def destination_for(self, task_id, request):
+        if request:
+            return self.rkey(task_id), request.correlation_id or task_id
+        return self.rkey(task_id), task_id
+
+    def store_result(self, task_id, result, status,
+                     traceback=None, request=None, **kwargs):
         """Send task return value and status."""
+        routing_key, correlation_id = self.destination_for(task_id, request)
+        if not routing_key:
+            return
         with self.app.amqp.producer_pool.acquire(block=True) as producer:
-            producer.publish({'task_id': task_id, 'status': status,
-                              'result': self.encode_result(result, status),
-                              'traceback': traceback,
-                              'children': self.current_task_children()},
-                             exchange=self.exchange,
-                             routing_key=task_id.replace('-', ''),
-                             serializer=self.serializer,
-                             retry=True, retry_policy=self.retry_policy,
-                             declare=[self._create_binding(task_id)])
+            producer.publish(
+                {'task_id': task_id, 'status': status,
+                 'result': self.encode_result(result, status),
+                 'traceback': traceback,
+                 'children': self.current_task_children(request)},
+                exchange=self.exchange,
+                routing_key=routing_key,
+                correlation_id=correlation_id,
+                serializer=self.serializer,
+                retry=True, retry_policy=self.retry_policy,
+                declare=self.on_reply_declare(task_id),
+                delivery_mode=self.delivery_mode,
+            )
         return result
 
+    def on_reply_declare(self, task_id):
+        return [self._create_binding(task_id)]
+
     def wait_for(self, task_id, timeout=None, cache=True, propagate=True,
+                 READY_STATES=states.READY_STATES,
+                 PROPAGATE_STATES=states.PROPAGATE_STATES,
                  **kwargs):
         cached_meta = self._cache.get(task_id)
         if cache and cached_meta and \
-                cached_meta['status'] in states.READY_STATES:
+                cached_meta['status'] in READY_STATES:
             meta = cached_meta
         else:
             try:
@@ -146,24 +153,22 @@ class AMQPBackend(BaseDictBackend):
             except socket.timeout:
                 raise TimeoutError('The operation timed out.')
 
-        state = meta['status']
-        if state == states.SUCCESS:
-            return meta['result']
-        elif state in states.PROPAGATE_STATES:
-            if propagate:
-                raise self.exception_to_python(meta['result'])
-            return meta['result']
-        else:
-            return self.wait_for(task_id, timeout, cache)
+        if meta['status'] in PROPAGATE_STATES and propagate:
+            raise self.exception_to_python(meta['result'])
+        # consume() always returns READY_STATE.
+        return meta['result']
 
     def get_task_meta(self, task_id, backlog_limit=1000):
         # Polling and using basic_get
         with self.app.pool.acquire_channel(block=True) as (_, channel):
             binding = self._create_binding(task_id)(channel)
             binding.declare()
+
             prev = latest = acc = None
-            for i in xrange(backlog_limit):  # spool ffwd
-                prev, latest, acc = latest, acc, binding.get(no_ack=False)
+            for i in range(backlog_limit):  # spool ffwd
+                prev, latest, acc = latest, acc, binding.get(
+                    accept=self.accept, no_ack=False,
+                )
                 if not acc:  # no more messages
                     break
                 if prev:
@@ -186,14 +191,14 @@ class AMQPBackend(BaseDictBackend):
                     return {'status': states.PENDING, 'result': None}
     poll = get_task_meta  # XXX compat
 
-    def drain_events(self, connection, consumer, timeout=None, now=time.time):
-        wait = connection.drain_events
+    def drain_events(self, connection, consumer,
+                     timeout=None, now=monotonic, wait=None):
+        wait = wait or connection.drain_events
         results = {}
 
         def callback(meta, message):
             if meta['status'] in states.READY_STATES:
-                uuid = repair_uuid(message.delivery_info['routing_key'])
-                results[uuid] = meta
+                results[meta['task_id']] = meta
 
         consumer.callbacks[:] = [callback]
         time_start = now()
@@ -209,33 +214,65 @@ class AMQPBackend(BaseDictBackend):
         return results
 
     def consume(self, task_id, timeout=None):
+        wait = self.drain_events
         with self.app.pool.acquire_channel(block=True) as (conn, channel):
             binding = self._create_binding(task_id)
-            with self.Consumer(channel, binding, no_ack=True) as consumer:
-                return self.drain_events(conn, consumer, timeout).values()[0]
+            with self.Consumer(channel, binding,
+                               no_ack=True, accept=self.accept) as consumer:
+                while 1:
+                    try:
+                        return wait(conn, consumer, timeout)[task_id]
+                    except KeyError:
+                        continue
 
-    def get_many(self, task_ids, timeout=None, **kwargs):
+    def _many_bindings(self, ids):
+        return [self._create_binding(task_id) for task_id in ids]
+
+    def get_many(self, task_ids, timeout=None,
+                 now=monotonic, getfields=itemgetter('status', 'task_id'),
+                 READY_STATES=states.READY_STATES,
+                 PROPAGATE_STATES=states.PROPAGATE_STATES, **kwargs):
         with self.app.pool.acquire_channel(block=True) as (conn, channel):
             ids = set(task_ids)
             cached_ids = set()
+            mark_cached = cached_ids.add
             for task_id in ids:
                 try:
                     cached = self._cache[task_id]
                 except KeyError:
                     pass
                 else:
-                    if cached['status'] in states.READY_STATES:
+                    if cached['status'] in READY_STATES:
                         yield task_id, cached
-                        cached_ids.add(task_id)
-            ids ^= cached_ids
+                        mark_cached(task_id)
+            ids.difference_update(cached_ids)
+            results = deque()
+            push_result = results.append
+            push_cache = self._cache.__setitem__
+            to_exception = self.exception_to_python
 
-            bindings = [self._create_binding(task_id) for task_id in task_ids]
-            with self.Consumer(channel, bindings, no_ack=True) as consumer:
+            def on_message(message):
+                body = message.decode()
+                state, uid = getfields(body)
+                if state in READY_STATES:
+                    if state in PROPAGATE_STATES:
+                        body['result'] = to_exception(body['result'])
+                    push_result(body) \
+                        if uid in task_ids else push_cache(uid, body)
+
+            bindings = self._many_bindings(task_ids)
+            with self.Consumer(channel, bindings, on_message=on_message,
+                               accept=self.accept, no_ack=True):
+                wait = conn.drain_events
+                popleft = results.popleft
                 while ids:
-                    r = self.drain_events(conn, consumer, timeout)
-                    ids ^= set(r)
-                    for ready_id, ready_meta in r.iteritems():
-                        yield ready_id, ready_meta
+                    wait(timeout=timeout)
+                    while results:
+                        state = popleft()
+                        task_id = state['task_id']
+                        ids.discard(task_id)
+                        push_cache(task_id, state)
+                        yield task_id, state
 
     def reload_task_result(self, task_id):
         raise NotImplementedError(
