@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -* coding: utf-8 -*-
 """
     celery.backends.cassandra
     ~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -20,15 +20,18 @@ import time
 
 from celery import states
 from celery.exceptions import ImproperlyConfigured
+from celery.five import monotonic
 from celery.utils.log import get_logger
 from celery.utils.timeutils import maybe_timedelta, timedelta_seconds
 
-from .base import BaseDictBackend
+from .base import BaseBackend
+
+__all__ = ['CassandraBackend']
 
 logger = get_logger(__name__)
 
 
-class CassandraBackend(BaseDictBackend):
+class CassandraBackend(BaseBackend):
     """Highly fault tolerant Cassandra backend.
 
     .. attribute:: servers
@@ -100,7 +103,7 @@ class CassandraBackend(BaseDictBackend):
         self._column_family = None
 
     def _retry_on_error(self, fun, *args, **kwargs):
-        ts = time.time() + self._retry_timeout
+        ts = monotonic() + self._retry_timeout
         while 1:
             try:
                 return fun(*args, **kwargs)
@@ -110,8 +113,8 @@ class CassandraBackend(BaseDictBackend):
                     pycassa.AllServersUnavailable,
                     socket.error,
                     socket.timeout,
-                    Thrift.TException), exc:
-                if time.time() > ts:
+                    Thrift.TException) as exc:
+                if monotonic() > ts:
                     raise
                 logger.warning('Cassandra error: %r. Retrying...', exc)
                 time.sleep(self._retry_wait)
@@ -132,7 +135,8 @@ class CassandraBackend(BaseDictBackend):
         if self._column_family is not None:
             self._column_family = None
 
-    def _store_result(self, task_id, result, status, traceback=None):
+    def _store_result(self, task_id, result, status,
+                      traceback=None, request=None, **kwargs):
         """Store return value and status of an executed task."""
 
         def _do_store():
@@ -141,7 +145,9 @@ class CassandraBackend(BaseDictBackend):
             meta = {'status': status,
                     'date_done': date_done.strftime('%Y-%m-%dT%H:%M:%SZ'),
                     'traceback': self.encode(traceback),
-                    'children': self.encode(self.current_task_children())}
+                    'children': self.encode(
+                        self.current_task_children(request),
+                    )}
             if self.detailed_mode:
                 meta['result'] = result
                 cf.insert(task_id, {date_done: self.encode(meta)},
@@ -161,7 +167,7 @@ class CassandraBackend(BaseDictBackend):
             try:
                 if self.detailed_mode:
                     row = cf.get(task_id, column_reversed=True, column_count=1)
-                    meta = self.decode(row.values()[0])
+                    meta = self.decode(list(row.values())[0])
                     meta['task_id'] = task_id
                 else:
                     obj = cf.get(task_id)
