@@ -3,7 +3,7 @@
     celery.bin.celeryd_detach
     ~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    Program used to daemonize celeryd.
+    Program used to daemonize the worker
 
     Using :func:`os.execv` because forking and multiprocessing
     leads to weird issues (it was a long time ago now, but it
@@ -11,7 +11,6 @@
 
 """
 from __future__ import absolute_import
-from __future__ import with_statement
 
 import celery
 import os
@@ -24,6 +23,8 @@ from celery.utils.log import get_logger
 
 from celery.bin.base import daemon_options, Option
 
+__all__ = ['detached_celeryd', 'detach']
+
 logger = get_logger(__name__)
 
 C_FAKEFORK = os.environ.get('C_FAKEFORK')
@@ -36,14 +37,16 @@ OPTION_LIST = daemon_options(default_pidfile='celeryd.pid') + (
 
 
 def detach(path, argv, logfile=None, pidfile=None, uid=None,
-           gid=None, umask=None, working_directory=None, fake=False):
+           gid=None, umask=0, working_directory=None, fake=False, app=None):
     fake = 1 if C_FAKEFORK else fake
     with detached(logfile, pidfile, uid, gid, umask, working_directory, fake):
         try:
             os.execv(path, [path] + argv)
         except Exception:
-            from celery import current_app
-            current_app.log.setup_logging_subsystem('ERROR', logfile)
+            if app is None:
+                from celery import current_app
+                app = current_app
+            app.log.setup_logging_subsystem('ERROR', logfile)
             logger.critical("Can't exec %r", ' '.join([path] + argv),
                             exc_info=True)
         return EX_FAILURE
@@ -77,9 +80,9 @@ class PartialOptionParser(OptionParser):
                 nargs = option.nargs
                 if len(rargs) < nargs:
                     if nargs == 1:
-                        self.error('%s option requires an argument' % opt)
+                        self.error('{0} requires an argument'.format(opt))
                     else:
-                        self.error('%s option requires %d arguments' % (
+                        self.error('{0} requires {1} arguments'.format(
                             opt, nargs))
                 elif nargs == 1:
                     value = rargs.pop(0)
@@ -88,7 +91,7 @@ class PartialOptionParser(OptionParser):
                     del rargs[0:nargs]
 
             elif had_explicit_value:
-                self.error('%s option does not take a value' % opt)
+                self.error('{0} option does not take a value'.format(opt))
             else:
                 value = None
             option.process(opt, value, values, self)
@@ -109,11 +112,17 @@ class detached_celeryd(object):
     option_list = OPTION_LIST
     usage = '%prog [options] [celeryd options]'
     version = celery.VERSION_BANNER
-    description = ('Detaches Celery worker nodes.  See `celeryd --help` '
+    description = ('Detaches Celery worker nodes.  See `celery worker --help` '
                    'for the list of supported worker arguments.')
     command = sys.executable
     execv_path = sys.executable
-    execv_argv = ['-m', 'celery.bin.celeryd']
+    if sys.version_info < (2, 7):  # does not support pkg/__main__.py
+        execv_argv = ['-m', 'celery.__main__', 'worker']
+    else:
+        execv_argv = ['-m', 'celery', 'worker']
+
+    def __init__(self, app=None):
+        self.app = app
 
     def Parser(self, prog_name):
         return PartialOptionParser(prog=prog_name,
@@ -126,9 +135,9 @@ class detached_celeryd(object):
         parser = self.Parser(prog_name)
         options, values = parser.parse_args(argv)
         if options.logfile:
-            parser.leftovers.append('--logfile=%s' % (options.logfile, ))
+            parser.leftovers.append('--logfile={0}'.format(options.logfile))
         if options.pidfile:
-            parser.leftovers.append('--pidfile=%s' % (options.pidfile, ))
+            parser.leftovers.append('--pidfile={0}'.format(options.pidfile))
         return options, values, parser.leftovers
 
     def execute_from_commandline(self, argv=None):
@@ -145,13 +154,15 @@ class detached_celeryd(object):
                     config.append(arg)
         prog_name = os.path.basename(argv[0])
         options, values, leftovers = self.parse_options(prog_name, argv[1:])
-        sys.exit(detach(path=self.execv_path,
-                 argv=self.execv_argv + leftovers + config,
-                 **vars(options)))
+        sys.exit(detach(
+            app=self.app, path=self.execv_path,
+            argv=self.execv_argv + leftovers + config,
+            **vars(options)
+        ))
 
 
-def main():
-    detached_celeryd().execute_from_commandline()
+def main(app=None):
+    detached_celeryd(app).execute_from_commandline()
 
 if __name__ == '__main__':  # pragma: no cover
     main()
