@@ -37,7 +37,7 @@ In the consumer:
 
        def run(self, **kwargs):
            results = []
-           for x in xrange(100):
+           for x in range(100):
                # Check after every 5 loops..
                if x % 5 == 0:  # alternatively, check when some timer is due
                    if self.is_aborted(**kwargs):
@@ -83,9 +83,11 @@ have it block until the task is finished.
 """
 from __future__ import absolute_import
 
-from celery.task.base import Task
+from celery import Task
 from celery.result import AsyncResult
 
+__all__ = ['AbortableAsyncResult', 'AbortableTask']
+
 
 """
 Task States
@@ -112,7 +114,7 @@ class AbortableAsyncResult(AsyncResult):
     """
 
     def is_aborted(self):
-        """Returns :const:`True` if the task is (being) aborted."""
+        """Return :const:`True` if the task is (being) aborted."""
         return self.state == ABORTED
 
     def abort(self):
@@ -141,17 +143,17 @@ class AbortableTask(Task):
     the call evaluates to :const:`True`.
 
     """
+    abstract = True
 
-    @classmethod
-    def AsyncResult(cls, task_id):
-        """Returns the accompanying AbortableAsyncResult instance."""
-        return AbortableAsyncResult(task_id, backend=cls.backend)
+    def AsyncResult(self, task_id):
+        """Return the accompanying AbortableAsyncResult instance."""
+        return AbortableAsyncResult(task_id, backend=self.backend)
 
     def is_aborted(self, **kwargs):
         """Checks against the backend whether this
         :class:`AbortableAsyncResult` is :const:`ABORTED`.
 
-        Always returns :const:`False` in case the `task_id` parameter
+        Always return :const:`False` in case the `task_id` parameter
         refers to a regular (non-abortable) :class:`Task`.
 
         Be aware that invoking this method will cause a hit in the
