@@ -28,7 +28,7 @@ to store it in a database.
         from collections import Counter
         count = Counter(request.kwargs['url'] for request in requests)
         for url, count in count.items():
-            print('>>> Clicks: %s -> %s' % (url, count))
+            print('>>> Clicks: {0} -> {1}'.format(url, count))
 
 
 Then you can ask for a click to be counted by doing::
@@ -84,13 +84,15 @@ Using the API is done as follows::
 from __future__ import absolute_import
 
 from itertools import count
-from Queue import Empty, Queue
 
 from celery.task import Task
+from celery.five import Empty, Queue
 from celery.utils.log import get_logger
 from celery.worker.job import Request
 from celery.utils import noop
 
+__all__ = ['Batches']
+
 logger = get_logger(__name__)
 
 
@@ -122,7 +124,7 @@ def apply_batches_task(task, args, loglevel, logfile):
     task.push_request(loglevel=loglevel, logfile=logfile)
     try:
         result = task(*args)
-    except Exception, exc:
+    except Exception as exc:
         result = None
         logger.error('Error: %r', exc, exc_info=True)
     finally:
@@ -176,12 +178,12 @@ class Batches(Task):
 
     def __init__(self):
         self._buffer = Queue()
-        self._count = count(1).next
+        self._count = count(1)
         self._tref = None
         self._pool = None
 
     def run(self, requests):
-        raise NotImplementedError('%r must implement run(requests)' % (self, ))
+        raise NotImplementedError('must implement run(requests)')
 
     def Strategy(self, task, app, consumer):
         self._pool = consumer.pool
@@ -193,7 +195,7 @@ class Batches(Task):
         put_buffer = self._buffer.put
         flush_buffer = self._do_flush
 
-        def task_message_handler(message, body, ack):
+        def task_message_handler(message, body, ack, reject, callbacks, **kw):
             request = Req(body, on_ack=ack, app=app, hostname=hostname,
                           events=eventer, task=task,
                           connection_errors=connection_errors,
@@ -201,10 +203,11 @@ class Batches(Task):
             put_buffer(request)
 
             if self._tref is None:     # first request starts flush timer.
-                self._tref = timer.apply_interval(self.flush_interval * 1000.0,
-                                                  flush_buffer)
+                self._tref = timer.call_repeatedly(
+                    self.flush_interval, flush_buffer,
+                )
 
-            if not self._count() % self.flush_every:
+            if not next(self._count) % self.flush_every:
                 flush_buffer()
 
         return task_message_handler
