@@ -8,12 +8,23 @@
 """
 from __future__ import absolute_import
 
+from .five import string_t
+
 from billiard.exceptions import (  # noqa
     SoftTimeLimitExceeded, TimeLimitExceeded, WorkerLostError, Terminated,
 )
 
+__all__ = ['SecurityError', 'Ignore', 'SystemTerminate', 'QueueNotFound',
+           'ImproperlyConfigured', 'NotRegistered', 'AlreadyRegistered',
+           'TimeoutError', 'MaxRetriesExceededError', 'Retry',
+           'TaskRevokedError', 'NotConfigured', 'AlwaysEagerIgnored',
+           'InvalidTaskError', 'ChordError', 'CPendingDeprecationWarning',
+           'CDeprecationWarning', 'FixupWarning', 'DuplicateNodenameWarning',
+           'SoftTimeLimitExceeded', 'TimeLimitExceeded', 'WorkerLostError',
+           'Terminated']
+
 UNREGISTERED_FMT = """\
-Task of kind %s is not registered, please make sure it's imported.\
+Task of kind {0} is not registered, please make sure it's imported.\
 """
 
 
@@ -29,6 +40,18 @@ class Ignore(Exception):
     """A task can raise this to ignore doing state updates."""
 
 
+class Reject(Exception):
+    """A task can raise this if it wants to reject/requeue the message."""
+
+    def __init__(self, reason=None, requeue=False):
+        self.reason = reason
+        self.requeue = requeue
+        super(Reject, self).__init__(reason, requeue)
+
+    def __repr__(self):
+        return 'reject requeue=%s: %s' % (self.requeue, self.reason)
+
+
 class SystemTerminate(SystemExit):
     """Signals that the worker should terminate."""
 
@@ -45,7 +68,7 @@ class NotRegistered(KeyError):
     """The task is not registered."""
 
     def __repr__(self):
-        return UNREGISTERED_FMT % str(self)
+        return UNREGISTERED_FMT.format(self)
 
 
 class AlreadyRegistered(Exception):
@@ -60,7 +83,7 @@ class MaxRetriesExceededError(Exception):
     """The tasks max restart limit has been exceeded."""
 
 
-class RetryTaskError(Exception):
+class Retry(Exception):
     """The task is to be retried later."""
 
     #: Optional message describing context of retry.
@@ -75,7 +98,7 @@ class RetryTaskError(Exception):
     def __init__(self, message=None, exc=None, when=None, **kwargs):
         from kombu.utils.encoding import safe_repr
         self.message = message
-        if isinstance(exc, basestring):
+        if isinstance(exc, string_t):
             self.exc, self.excs = None, exc
         else:
             self.exc, self.excs = exc, safe_repr(exc) if exc else None
@@ -84,18 +107,19 @@ class RetryTaskError(Exception):
 
     def humanize(self):
         if isinstance(self.when, int):
-            return 'in %ss' % self.when
-        return 'at %s' % (self.when, )
+            return 'in {0.when}s'.format(self)
+        return 'at {0.when}'.format(self)
 
     def __str__(self):
         if self.message:
             return self.message
         if self.excs:
-            return 'Retry %s: %s' % (self.humanize(), self.excs)
-        return 'Retry %s' % self.humanize()
+            return 'Retry {0}: {1}'.format(self.humanize(), self.excs)
+        return 'Retry {0}'.format(self.humanize())
 
     def __reduce__(self):
         return self.__class__, (self.message, self.excs, self.when)
+RetryTaskError = Retry   # XXX compat
 
 
 class TaskRevokedError(Exception):
@@ -114,6 +138,14 @@ class InvalidTaskError(Exception):
     """The task has invalid data or is not properly constructed."""
 
 
+class IncompleteStream(Exception):
+    """Found the end of a stream of data, but the data is not yet complete."""
+
+
+class ChordError(Exception):
+    """A task part of the chord raised an exception."""
+
+
 class CPendingDeprecationWarning(PendingDeprecationWarning):
     pass
 
@@ -122,9 +154,9 @@ class CDeprecationWarning(DeprecationWarning):
     pass
 
 
-class IncompleteStream(Exception):
-    """Found the end of a stream of data, but the data is not yet complete."""
+class FixupWarning(UserWarning):
+    pass
 
 
-class ChordError(Exception):
-    """A task part of the chord raised an exception."""
+class DuplicateNodenameWarning(UserWarning):
+    """Multiple workers are using the same nodename."""
