@@ -18,6 +18,7 @@ from kombu.utils.compat import OrderedDict
 
 from . import current_app
 from . import states
+from ._state import task_join_will_block
 from .app import app_or_default
 from .datastructures import DependencyGraph, GraphFormatter
 from .exceptions import IncompleteStream, TimeoutError
@@ -26,6 +27,17 @@ from .five import items, range, string_t, monotonic
 __all__ = ['ResultBase', 'AsyncResult', 'ResultSet', 'GroupResult',
            'EagerResult', 'result_from_tuple']
 
+E_WOULDBLOCK = """\
+Never call result.get() within a task!
+See http://docs.celeryq.org/en/latest/userguide/tasks.html\
+#task-synchronous-subtasks
+"""
+
+
+def assert_will_not_block():
+    if task_join_will_block():
+        pass   # TODO future version: raise
+
 
 class ResultBase(object):
     """Base class for all results"""
@@ -114,6 +126,7 @@ class AsyncResult(ResultBase):
         be re-raised.
 
         """
+        assert_will_not_block()
         if propagate and self.parent:
             for node in reversed(list(self._parents())):
                 node.get(propagate=True, timeout=timeout, interval=interval)
@@ -154,6 +167,8 @@ class AsyncResult(ResultBase):
 
         .. code-block:: python
 
+            >>> from proj.tasks import A
+
             >>> result = A.delay(10)
             >>> list(result.collect())
             [0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
@@ -519,6 +534,7 @@ class ResultSet(ResultBase):
             seconds.
 
         """
+        assert_will_not_block()
         time_start = monotonic()
         remaining = None
 
@@ -570,6 +586,7 @@ class ResultSet(ResultBase):
         result backends.
 
         """
+        assert_will_not_block()
         order_index = None if callback else dict(
             (result.id, i) for i, result in enumerate(self.results)
         )
@@ -643,8 +660,9 @@ class GroupResult(ResultSet):
 
         Example::
 
-            >>> result.save()
-            >>> result = GroupResult.restore(group_id)
+            >>> def save_and_restore(result):
+            ...     result.save()
+            ...     result = GroupResult.restore(result.id)
 
         """
         return (backend or self.app.backend).save_group(self.id, self)
