@@ -13,18 +13,23 @@ import sys
 from contextlib import contextmanager
 
 from celery.exceptions import SecurityError
+from celery.five import reraise
 
 try:
     from OpenSSL import crypto
 except ImportError:  # pragma: no cover
     crypto = None    # noqa
 
+__all__ = ['reraise_errors']
+
 
 @contextmanager
-def reraise_errors(msg='%r', errors=None):
+def reraise_errors(msg='{0!r}', errors=None):
     assert crypto is not None
     errors = (crypto.Error, ) if errors is None else errors
     try:
         yield
-    except errors, exc:
-        raise SecurityError, SecurityError(msg % (exc, )), sys.exc_info()[2]
+    except errors as exc:
+        reraise(SecurityError,
+                SecurityError(msg.format(exc)),
+                sys.exc_info()[2])
