@@ -59,6 +59,10 @@ Misc.
 """
 from __future__ import absolute_import
 
+__all__ = ['PENDING', 'RECEIVED', 'STARTED', 'SUCCESS', 'FAILURE',
+           'REVOKED', 'RETRY', 'IGNORED', 'READY_STATES', 'UNREADY_STATES',
+           'EXCEPTION_STATES', 'PROPAGATE_STATES', 'precedence', 'state']
+
 #: State precedence.
 #: None represents the precedence of an unknown state.
 #: Lower index means higher precedence.
@@ -123,14 +127,22 @@ class state(str):
     def __le__(self, other):
         return self.compare(other, lambda a, b: a >= b)
 
+#: Task state is unknown (assumed pending since you know the id).
 PENDING = 'PENDING'
+#: Task was received by a worker.
 RECEIVED = 'RECEIVED'
+#: Task was started by a worker (:setting:`CELERY_TRACK_STARTED`).
 STARTED = 'STARTED'
+#: Task succeeded
 SUCCESS = 'SUCCESS'
+#: Task failed
 FAILURE = 'FAILURE'
+#: Task was revoked.
 REVOKED = 'REVOKED'
+#: Task is waiting for retry.
 RETRY = 'RETRY'
 IGNORED = 'IGNORED'
+REJECTED = 'REJECTED'
 
 READY_STATES = frozenset([SUCCESS, FAILURE, REVOKED])
 UNREADY_STATES = frozenset([PENDING, RECEIVED, STARTED, RETRY])
