@@ -12,7 +12,7 @@
 from __future__ import absolute_import
 
 from celery._state import current_app, current_task as current
-from celery.__compat__ import MagicModule, recreate_module
+from celery.five import MagicModule, recreate_module
 from celery.local import Proxy
 
 __all__ = [
@@ -23,7 +23,7 @@ __all__ = [
 
 STATICA_HACK = True
 globals()['kcah_acitats'[::-1].upper()] = False
-if STATICA_HACK:
+if STATICA_HACK:  # pragma: no cover
     # This is never executed, but tricks static analyzers (PyDev, PyCharm,
     # pylint, etc.) into knowing the types of these symbols, and what
     # they contain.
