@@ -16,7 +16,7 @@ from celery.utils.log import (
     task_logger,
     in_sighandler,
     logger_isa,
-    _patch_logger_class,
+    ensure_process_aware_logger,
 )
 from celery.tests.case import (
     AppCase, Mock, SkipTest,
@@ -342,11 +342,7 @@ class test_task_logger(test_default_logger):
 class test_patch_logger_cls(AppCase):
 
     def test_patches(self):
-        _patch_logger_class()
-        self.assertTrue(logging.getLoggerClass()._signal_safe)
-        _patch_logger_class()
-        self.assertTrue(logging.getLoggerClass()._signal_safe)
-
+        ensure_process_aware_logger()
         with in_sighandler():
             logging.getLoggerClass().log(get_logger('test'))
 
