@@ -1,25 +1,30 @@
-"""
-Tests of celery.app.utils
-"""
-
 from __future__ import absolute_import
 
+from collections import Mapping, MutableMapping
 
-import unittest
+from celery.app.utils import Settings, bugreport
+
+from celery.tests.case import AppCase, Mock
 
 
-class TestSettings(unittest.TestCase):
+class TestSettings(AppCase):
     """
     Tests of celery.app.utils.Settings
     """
     def test_is_mapping(self):
         """Settings should be a collections.Mapping"""
-        from celery.app.utils import Settings
-        from collections import Mapping
         self.assertTrue(issubclass(Settings, Mapping))
 
     def test_is_mutable_mapping(self):
         """Settings should be a collections.MutableMapping"""
-        from celery.app.utils import Settings
-        from collections import MutableMapping
         self.assertTrue(issubclass(Settings, MutableMapping))
+
+
+class test_bugreport(AppCase):
+
+    def test_no_conn_driver_info(self):
+        self.app.connection = Mock()
+        conn = self.app.connection.return_value = Mock()
+        conn.transport = None
+
+        bugreport(self.app)
