@@ -2,8 +2,6 @@ from __future__ import absolute_import
 
 from datetime import timedelta
 
-from mock import Mock, patch
-from nose import SkipTest
 from pickle import loads, dumps
 
 from kombu.utils import cached_property, uuid
@@ -14,7 +12,9 @@ from celery.datastructures import AttributeDict
 from celery.exceptions import ImproperlyConfigured
 from celery.utils.timeutils import timedelta_seconds
 
-from celery.tests.case import AppCase, depends_on_current_app
+from celery.tests.case import (
+    AppCase, Mock, SkipTest, depends_on_current_app, patch,
+)
 
 
 class Redis(object):
