@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import
 
-from .signal import Signal  # noqa
+from .signal import Signal
+
+__all__ = ['Signal']
