@@ -8,10 +8,14 @@
 """
 from __future__ import absolute_import
 
-import textwrap
+from textwrap import fill
 
 from pprint import pformat
 
+__all__ = ['dedent_initial', 'dedent', 'fill_paragraphs', 'join',
+           'ensure_2lines', 'abbr', 'abbrtask', 'indent', 'truncate',
+           'pluralize', 'pretty']
+
 
 def dedent_initial(s, n=4):
     return s[n:] if s[:n] == ' ' * n else s
@@ -22,7 +26,7 @@ def dedent(s, n=4, sep='\n'):
 
 
 def fill_paragraphs(s, width, sep='\n'):
-    return sep.join(textwrap.fill(p, width) for p in s.split(sep))
+    return sep.join(fill(p, width) for p in s.split(sep))
 
 
 def join(l, sep='\n'):
@@ -73,8 +77,10 @@ def pluralize(n, text, suffix='s'):
 
 def pretty(value, width=80, nl_width=80, sep='\n', **kw):
     if isinstance(value, dict):
-        return '{%s %s' % (sep, pformat(value, 4, nl_width)[1:])
+        return '{{{0} {1}'.format(sep, pformat(value, 4, nl_width)[1:])
     elif isinstance(value, tuple):
-        return '%s%s%s' % (sep, ' ' * 4, pformat(value, width=nl_width, **kw))
+        return '{0}{1}{2}'.format(
+            sep, ' ' * 4, pformat(value, width=nl_width, **kw),
+        )
     else:
         return pformat(value, width=width, **kw)
