@@ -11,55 +11,52 @@ from __future__ import absolute_import
 import os
 import time as _time
 
-from kombu.utils import cached_property
+from calendar import monthrange
+from datetime import date, datetime, timedelta, tzinfo
 
-from datetime import datetime, timedelta, tzinfo
-from dateutil import tz
-from dateutil.parser import parse as parse_iso8601
+from kombu.utils import cached_property, reprcall
+from kombu.utils.compat import timedelta_seconds
 
-from celery.exceptions import ImproperlyConfigured
+from pytz import timezone as _timezone, AmbiguousTimeError
 
+from celery.five import string_t
+
+from .functional import dictfilter
+from .iso8601 import parse_iso8601
 from .text import pluralize
 
-try:
-    import pytz
-    from pytz import AmbiguousTimeError
-except ImportError:                         # pragma: no cover
-    pytz = None                             # noqa
-
-    class AmbiguousTimeError(Exception):    # noqa
-        pass
-
+__all__ = ['LocalTimezone', 'timezone', 'maybe_timedelta', 'timedelta_seconds',
+           'delta_resolution', 'remaining', 'rate', 'weekday',
+           'humanize_seconds', 'maybe_iso8601', 'is_naive', 'make_aware',
+           'localize', 'to_utc', 'maybe_make_aware', 'ffwd', 'utcoffset',
+           'adjust_timestamp', 'maybe_s_to_ms']
 
 C_REMDEBUG = os.environ.get('C_REMDEBUG', False)
 
-
 DAYNAMES = 'sun', 'mon', 'tue', 'wed', 'thu', 'fri', 'sat'
-WEEKDAYS = dict((name, dow) for name, dow in zip(DAYNAMES, range(7)))
+WEEKDAYS = dict(zip(DAYNAMES, range(7)))
 
 RATE_MODIFIER_MAP = {'s': lambda n: n,
                      'm': lambda n: n / 60.0,
                      'h': lambda n: n / 60.0 / 60.0}
 
-
-HAVE_TIMEDELTA_TOTAL_SECONDS = hasattr(timedelta, 'total_seconds')
-
-TIME_UNITS = (('day', 60 * 60 * 24.0, lambda n: '%.2f' % n),
-              ('hour', 60 * 60.0, lambda n: '%.2f' % n),
-              ('minute', 60.0, lambda n: '%.2f' % n),
-              ('second', 1.0, lambda n: '%.2f' % n))
+TIME_UNITS = (('day', 60 * 60 * 24.0, lambda n: format(n, '.2f')),
+              ('hour', 60 * 60.0, lambda n: format(n, '.2f')),
+              ('minute', 60.0, lambda n: format(n, '.2f')),
+              ('second', 1.0, lambda n: format(n, '.2f')))
 
 ZERO = timedelta(0)
 
 _local_timezone = None
 
+__timezone__ = -_time.timezone
+__altzone__ = -_time.altzone
+
 
 class LocalTimezone(tzinfo):
-    """
-    Local time implementation taken from Python's docs.
+    """Local time implementation taken from Python's docs.
 
-    Used only when pytz isn't available, and most likely inaccurate. If you're
-    having trouble with this class, don't waste your time, just install pytz.
+    Used only when UTC is not enabled.
     """
 
     def __init__(self):
@@ -74,7 +71,7 @@ class LocalTimezone(tzinfo):
         tzinfo.__init__(self)
 
     def __repr__(self):
-        return "<LocalTimezone>"
+        return '<LocalTimezone>'
 
     def utcoffset(self, dt):
         if self._isdst(dt):
@@ -115,19 +112,14 @@ class _Zone(object):
     def to_system(self, dt):
         return localize(dt, self.local)
 
-    def to_local_fallback(self, dt, *args, **kwargs):
+    def to_local_fallback(self, dt):
         if is_naive(dt):
             return make_aware(dt, self.local)
         return localize(dt, self.local)
 
     def get_timezone(self, zone):
-        if isinstance(zone, basestring):
-            if pytz is None:
-                if zone == 'UTC':
-                    return tz.gettz('UTC')
-                raise ImproperlyConfigured(
-                    'Timezones requires the pytz library')
-            return pytz.timezone(zone)
+        if isinstance(zone, string_t):
+            return _timezone(zone)
         return zone
 
     @cached_property
@@ -147,29 +139,6 @@ def maybe_timedelta(delta):
     return delta
 
 
-if HAVE_TIMEDELTA_TOTAL_SECONDS:   # pragma: no cover
-
-    def timedelta_seconds(delta):
-        """Convert :class:`datetime.timedelta` to seconds.
-
-        Doesn't account for negative values.
-
-        """
-        return max(delta.total_seconds(), 0)
-
-else:  # pragma: no cover
-
-    def timedelta_seconds(delta):  # noqa
-        """Convert :class:`datetime.timedelta` to seconds.
-
-        Doesn't account for negative values.
-
-        """
-        if delta.days < 0:
-            return 0
-        return delta.days * 86400 + delta.seconds + (delta.microseconds / 10e5)
-
-
 def delta_resolution(dt, delta):
     """Round a datetime to the resolution of a timedelta.
 
@@ -192,7 +161,7 @@ def delta_resolution(dt, delta):
     return dt
 
 
-def remaining(start, ends_in, now=None, relative=False, debug=False):
+def remaining(start, ends_in, now=None, relative=False):
     """Calculate the remaining time for a start date and a timedelta.
 
     e.g. "how many seconds left for 30 seconds after start?"
@@ -211,17 +180,17 @@ def remaining(start, ends_in, now=None, relative=False, debug=False):
     if relative:
         end_date = delta_resolution(end_date, ends_in)
     ret = end_date - now
-    if C_REMDEBUG:
-        print('rem: NOW:%s START:%s END_DATE:%s REM:%s' % (
-            now, start, end_date, ret))
+    if C_REMDEBUG:  # pragma: no cover
+        print('rem: NOW:%r START:%r ENDS_IN:%r END_DATE:%s REM:%s' % (
+            now, start, ends_in, end_date, ret))
     return ret
 
 
 def rate(rate):
-    """Parses rate strings, such as `"100/m"`, `"2/h"` or `"0.5/s"`
-    and converts them to seconds."""
+    """Parse rate strings, such as `"100/m"`, `"2/h"` or `"0.5/s"`
+    and convert them to seconds."""
     if rate:
-        if isinstance(rate, basestring):
+        if isinstance(rate, string_t):
             ops, _, modifier = rate.partition('/')
             return RATE_MODIFIER_MAP[modifier or 's'](float(ops)) or 0
         return rate or 0
@@ -245,7 +214,7 @@ def weekday(name):
         raise KeyError(name)
 
 
-def humanize_seconds(secs, prefix='', sep=''):
+def humanize_seconds(secs, prefix='', sep='', now='now'):
     """Show seconds in human form, e.g. 60 is "1 minute", 7200 is "2
     hours".
 
@@ -257,9 +226,9 @@ def humanize_seconds(secs, prefix='', sep=''):
     for unit, divider, formatter in TIME_UNITS:
         if secs >= divider:
             w = secs / divider
-            return '%s%s%s %s' % (prefix, sep, formatter(w),
-                                  pluralize(w, unit))
-    return 'now'
+            return '{0}{1}{2} {3}'.format(prefix, sep, formatter(w),
+                                          pluralize(w, unit))
+    return now
 
 
 def maybe_iso8601(dt):
@@ -272,7 +241,7 @@ def maybe_iso8601(dt):
 
 
 def is_naive(dt):
-    """Returns :const:`True` if the datetime is naive
+    """Return :const:`True` if the datetime is naive
     (does not have timezone information)."""
     return dt.tzinfo is None or dt.tzinfo.utcoffset(dt) is None
 
@@ -317,5 +286,62 @@ def to_utc(dt):
 def maybe_make_aware(dt, tz=None):
     if is_naive(dt):
         dt = to_utc(dt)
-    return localize(dt,
-                    timezone.utc if tz is None else timezone.tz_or_local(tz))
+    return localize(
+        dt, timezone.utc if tz is None else timezone.tz_or_local(tz),
+    )
+
+
+class ffwd(object):
+    """Version of relativedelta that only supports addition."""
+
+    def __init__(self, year=None, month=None, weeks=0, weekday=None, day=None,
+                 hour=None, minute=None, second=None, microsecond=None,
+                 **kwargs):
+        self.year = year
+        self.month = month
+        self.weeks = weeks
+        self.weekday = weekday
+        self.day = day
+        self.hour = hour
+        self.minute = minute
+        self.second = second
+        self.microsecond = microsecond
+        self.days = weeks * 7
+        self._has_time = self.hour is not None or self.minute is not None
+
+    def __repr__(self):
+        return reprcall('ffwd', (), self._fields(weeks=self.weeks,
+                                                 weekday=self.weekday))
+
+    def __radd__(self, other):
+        if not isinstance(other, date):
+            return NotImplemented
+        year = self.year or other.year
+        month = self.month or other.month
+        day = min(monthrange(year, month)[1], self.day or other.day)
+        ret = other.replace(**dict(dictfilter(self._fields()),
+                            year=year, month=month, day=day))
+        if self.weekday is not None:
+            ret += timedelta(days=(7 - ret.weekday() + self.weekday) % 7)
+        return ret + timedelta(days=self.days)
+
+    def _fields(self, **extra):
+        return dictfilter({
+            'year': self.year, 'month': self.month, 'day': self.day,
+            'hour': self.hour, 'minute': self.minute,
+            'second': self.second, 'microsecond': self.microsecond,
+        }, **extra)
+
+
+def utcoffset():
+    if _time.daylight:
+        return (__timezone__ + __altzone__) // 3600
+    return __timezone__ // 3600
+
+
+def adjust_timestamp(ts, offset, here=utcoffset):
+    return ts - (offset - here()) * 3600
+
+
+def maybe_s_to_ms(v):
+    return int(float(v) * 1000.0) if v is not None else v
