@@ -219,7 +219,10 @@ class WorkController(object):
             self.stop()
 
     def register_with_event_loop(self, hub):
-        self.blueprint.send_all(self, 'register_with_event_loop', args=(hub, ))
+        self.blueprint.send_all(
+            self, 'register_with_event_loop', args=(hub, ),
+            description='hub.register',
+        )
 
     def _process_task_sem(self, req):
         return self._quick_acquire(self._process_task, req)
@@ -280,6 +283,10 @@ class WorkController(object):
             elif reload:
                 logger.debug('reloading module %s', module)
                 reload_from_cwd(sys.modules[module], reloader)
+
+        if self.consumer:
+            self.consumer.update_strategies()
+            self.consumer.reset_rate_limits()
         self.pool.restart()
 
     def info(self):
