@@ -15,14 +15,20 @@ import os
 import sys
 import platform
 import shelve
+import zlib
 
-from collections import defaultdict
-
-from kombu.serialization import pickle_protocol
+from kombu.serialization import pickle, pickle_protocol
 from kombu.utils import cached_property
 
 from celery import __version__
 from celery.datastructures import LimitedSet
+from celery.exceptions import SystemTerminate
+from celery.five import Counter
+
+__all__ = ['SOFTWARE_INFO', 'reserved_requests', 'active_requests',
+           'total_count', 'revoked', 'task_reserved', 'maybe_shutdown',
+           'task_accepted', 'task_ready', 'task_reserved', 'task_ready',
+           'Persistent']
 
 #: Worker software/platform information.
 SOFTWARE_INFO = {'sw_ident': 'py-celery',
@@ -30,11 +36,11 @@ SOFTWARE_INFO = {'sw_ident': 'py-celery',
                  'sw_sys': platform.system()}
 
 #: maximum number of revokes to keep in memory.
-REVOKES_MAX = 10000
+REVOKES_MAX = 50000
 
 #: how many seconds a revoke will be active before
 #: being expired when the max limit has been exceeded.
-REVOKE_EXPIRES = 3600
+REVOKE_EXPIRES = 10800
 
 #: set of all reserved :class:`~celery.worker.job.Request`'s.
 reserved_requests = set()
@@ -42,19 +48,26 @@ reserved_requests = set()
 #: set of currently active :class:`~celery.worker.job.Request`'s.
 active_requests = set()
 
-#: count of tasks executed by the worker, sorted by type.
-total_count = defaultdict(int)
+#: count of tasks accepted by the worker, sorted by type.
+total_count = Counter()
 
 #: the list of currently revoked tasks.  Persistent if statedb set.
 revoked = LimitedSet(maxlen=REVOKES_MAX, expires=REVOKE_EXPIRES)
 
-#: Updates global state when a task has been reserved.
+#: Update global state when a task has been reserved.
 task_reserved = reserved_requests.add
 
 should_stop = False
 should_terminate = False
 
 
+def maybe_shutdown():
+    if should_stop:
+        raise SystemExit()
+    elif should_terminate:
+        raise SystemTerminate()
+
+
 def task_accepted(request):
     """Updates global state when a task has been accepted."""
     active_requests.add(request)
@@ -73,8 +86,8 @@ C_BENCH_EVERY = int(os.environ.get('C_BENCH_EVERY') or
 if C_BENCH:  # pragma: no cover
     import atexit
 
-    from time import time
     from billiard import current_process
+    from celery.five import monotonic
     from celery.utils.debug import memdump, sample_mem
 
     all_count = 0
@@ -90,9 +103,10 @@ if C_BENCH:  # pragma: no cover
         @atexit.register
         def on_shutdown():
             if bench_first is not None and bench_last is not None:
-                print('- Time spent in benchmark: %r' % (
-                    bench_last - bench_first))
-                print('- Avg: %s' % (sum(bench_sample) / len(bench_sample)))
+                print('- Time spent in benchmark: {0!r}'.format(
+                      bench_last - bench_first))
+                print('- Avg: {0}'.format(
+                      sum(bench_sample) / len(bench_sample)))
                 memdump()
 
     def task_reserved(request):  # noqa
@@ -100,7 +114,7 @@ if C_BENCH:  # pragma: no cover
         global bench_first
         now = None
         if bench_start is None:
-            bench_start = now = time()
+            bench_start = now = monotonic()
         if bench_first is None:
             bench_first = now
 
@@ -112,10 +126,10 @@ if C_BENCH:  # pragma: no cover
         global bench_last
         all_count += 1
         if not all_count % bench_every:
-            now = time()
+            now = monotonic()
             diff = now - bench_start
-            print('- Time spent processing %s tasks (since first '
-                  'task received): ~%.4fs\n' % (bench_every, diff))
+            print('- Time spent processing {0} tasks (since first '
+                  'task received): ~{1:.4f}s\n'.format(bench_every, diff))
             sys.stdout.flush()
             bench_start = bench_last = now
             bench_sample.append(diff)
@@ -132,44 +146,87 @@ class Persistent(object):
     """
     storage = shelve
     protocol = pickle_protocol
+    compress = zlib.compress
+    decompress = zlib.decompress
     _is_open = False
 
-    def __init__(self, filename):
+    def __init__(self, state, filename, clock=None):
+        self.state = state
         self.filename = filename
-        self._load()
-
-    def save(self):
-        self.sync(self.db)
-        self.db.sync()
-        self.close()
-
-    def merge(self, d):
-        saved = d.get('revoked') or LimitedSet()
-        if isinstance(saved, LimitedSet):
-            revoked.update(saved)
-        else:
-            # (pre 3.0.18) used to be stored as dict
-            for item in saved:
-                revoked.add(item)
-        return d
-
-    def sync(self, d):
-        revoked.purge()
-        d['revoked'] = revoked
-        return d
+        self.clock = clock
+        self.merge()
 
     def open(self):
         return self.storage.open(
             self.filename, protocol=self.protocol, writeback=True,
         )
 
+    def merge(self):
+        self._merge_with(self.db)
+
+    def sync(self):
+        self._sync_with(self.db)
+        self.db.sync()
+
     def close(self):
         if self._is_open:
             self.db.close()
             self._is_open = False
 
-    def _load(self):
-        self.merge(self.db)
+    def save(self):
+        self.sync()
+        self.close()
+
+    def _merge_with(self, d):
+        self._merge_revoked(d)
+        self._merge_clock(d)
+        return d
+
+    def _sync_with(self, d):
+        self._revoked_tasks.purge()
+        d.update(
+            __proto__=3,
+            zrevoked=self.compress(self._dumps(self._revoked_tasks)),
+            clock=self.clock.forward() if self.clock else 0,
+        )
+        return d
+
+    def _merge_clock(self, d):
+        if self.clock:
+            d['clock'] = self.clock.adjust(d.get('clock') or 0)
+
+    def _merge_revoked(self, d):
+        try:
+            self._merge_revoked_v3(d['zrevoked'])
+        except KeyError:
+            try:
+                self._merge_revoked_v2(d.pop('revoked'))
+            except KeyError:
+                pass
+        # purge expired items at boot
+        self._revoked_tasks.purge()
+
+    def _merge_revoked_v3(self, zrevoked):
+        if zrevoked:
+            self._revoked_tasks.update(pickle.loads(self.decompress(zrevoked)))
+
+    def _merge_revoked_v2(self, saved):
+        if not isinstance(saved, LimitedSet):
+            # (pre 3.0.18) used to be stored as a dict
+            return self._merge_revoked_v1(saved)
+        self._revoked_tasks.update(saved)
+
+    def _merge_revoked_v1(self, saved):
+        add = self._revoked_tasks.add
+        for item in saved:
+            add(item)
+
+    def _dumps(self, obj):
+        return pickle.dumps(obj, protocol=self.protocol)
+
+    @property
+    def _revoked_tasks(self):
+        return self.state.revoked
 
     @cached_property
     def db(self):
