@@ -1,39 +1,39 @@
 from docutils import nodes
 
 from sphinx.environment import NoUri
-from sphinx.util.nodes import make_refnode
 
 APPATTRS = {
-    "amqp": "celery.app.amqp.AMQP",
-    "backend": "celery.backends.base.BaseBackend",
-    "control": "celery.app.control.Control",
-    "events": "celery.events.Events",
-    "loader": "celery.app.loaders.base.BaseLoader",
-    "log": "celery.app.log.Logging",
-    "pool": "kombu.connection.ConnectionPool",
-    "tasks": "celery.app.registry.Registry",
+    'amqp': 'celery.app.amqp.AMQP',
+    'backend': 'celery.backends.base.BaseBackend',
+    'control': 'celery.app.control.Control',
+    'events': 'celery.events.Events',
+    'loader': 'celery.app.loaders.base.BaseLoader',
+    'log': 'celery.app.log.Logging',
+    'pool': 'kombu.connection.ConnectionPool',
+    'tasks': 'celery.app.registry.Registry',
 
-    "AsyncResult": "celery.result.AsyncResult",
-    "GroupResult": "celery.result.GroupResult",
-    "Worker": "celery.apps.worker.Worker",
-    "WorkController": "celery.worker.WorkController",
-    "Beat": "celery.apps.beat.Beat",
-    "Task": "celery.app.task.Task",
-    "send_task": "celery.Celery.send_task",
+    'AsyncResult': 'celery.result.AsyncResult',
+    'GroupResult': 'celery.result.GroupResult',
+    'Worker': 'celery.apps.worker.Worker',
+    'WorkController': 'celery.worker.WorkController',
+    'Beat': 'celery.apps.beat.Beat',
+    'Task': 'celery.app.task.Task',
+    'send_task': 'celery.Celery.send_task',
+    'connection': 'celery.Celery.connection',
 }
 
 ABBRS = {
-    "Celery": "celery.Celery",
+    'Celery': 'celery.Celery',
 }
 
 ABBR_EMPTY = {
-    "exc": "celery.exceptions",
+    'exc': 'celery.exceptions',
 }
-DEFAULT_EMPTY = "celery.Celery"
+DEFAULT_EMPTY = 'celery.Celery'
 
 
 def typeify(S, type):
-    if type in ("meth", "func"):
+    if type in ('meth', 'func'):
         return S + '()'
     return S
 
@@ -65,9 +65,7 @@ def get_abbr(pre, rest, type):
     return ABBR_EMPTY.get(type, DEFAULT_EMPTY), rest, ABBR_EMPTY
 
 
-
 def resolve(S, type):
-    is_appattr = False
     if S.startswith('@'):
         S = S.lstrip('@-')
         try:
@@ -91,30 +89,29 @@ def basename(module_fqdn):
 def modify_textnode(T, newtarget, node, src_dict, type):
     src = node.children[0].rawsource
     return nodes.Text(
-        typeify(basename(T), type) if '~' in src
-                                   else typeify(shorten(T, newtarget,
-                                                        src_dict), type),
+        (typeify(basename(T), type) if '~' in src
+         else typeify(shorten(T, newtarget, src_dict), type)),
         src,
     )
 
 
 def maybe_resolve_abbreviations(app, env, node, contnode):
     domainname = node.get('refdomain')
-    target = node["reftarget"]
-    type = node["reftype"]
+    target = node['reftarget']
+    type = node['reftype']
     if target.startswith('@'):
         newtarget, src_dict = resolve(target, type)
-        node["reftarget"] = newtarget
+        node['reftarget'] = newtarget
         # shorten text if '~' is not enabled.
         if len(contnode) and isinstance(contnode[0], nodes.Text):
                 contnode[0] = modify_textnode(target, newtarget, node,
                                               src_dict, type)
         if domainname:
             try:
-                domain = env.domains[node.get("refdomain")]
+                domain = env.domains[node.get('refdomain')]
             except KeyError:
                 raise NoUri
-            return domain.resolve_xref(env, node["refdoc"], app.builder,
+            return domain.resolve_xref(env, node['refdoc'], app.builder,
                                        type, newtarget,
                                        node, contnode)
 
@@ -123,32 +120,32 @@ def setup(app):
     app.connect('missing-reference', maybe_resolve_abbreviations)
 
     app.add_crossref_type(
-        directivename="setting",
-        rolename="setting",
-        indextemplate="pair: %s; setting",
+        directivename='setting',
+        rolename='setting',
+        indextemplate='pair: %s; setting',
     )
     app.add_crossref_type(
-        directivename="sig",
-        rolename="sig",
-        indextemplate="pair: %s; sig",
+        directivename='sig',
+        rolename='sig',
+        indextemplate='pair: %s; sig',
     )
     app.add_crossref_type(
-        directivename="state",
-        rolename="state",
-        indextemplate="pair: %s; state",
+        directivename='state',
+        rolename='state',
+        indextemplate='pair: %s; state',
     )
     app.add_crossref_type(
-        directivename="control",
-        rolename="control",
-        indextemplate="pair: %s; control",
+        directivename='control',
+        rolename='control',
+        indextemplate='pair: %s; control',
     )
     app.add_crossref_type(
-        directivename="signal",
-        rolename="signal",
-        indextemplate="pair: %s; signal",
+        directivename='signal',
+        rolename='signal',
+        indextemplate='pair: %s; signal',
     )
     app.add_crossref_type(
-        directivename="event",
-        rolename="event",
-        indextemplate="pair: %s; event",
+        directivename='event',
+        rolename='event',
+        indextemplate='pair: %s; event',
     )
