@@ -15,15 +15,21 @@ using the `-A` / `--app` option::
 
     $ celery -A myapp worker -l info
 
+With the `-A myproj` argument the program will search for an app
+instance in the module ``myproj``.  You can also specify an explicit
+name using the fully qualified form::
+
+    $ celery -A myapp:app worker -l info
+
 """
 from celery import Celery
 
-celery = Celery('myapp', broker='amqp://guest@localhost//')
+app = Celery('myapp', broker='amqp://guest@localhost//')
 
 
-@celery.task()
+@app.task()
 def add(x, y):
     return x + y
 
 if __name__ == '__main__':
-    celery.start()
+    app.start()
