@@ -19,10 +19,11 @@
 #    ...                           A_callback.subtask()), countdown=1)
 
 
-from celery import chord, task, subtask
+from celery import chord, group, task, signature, uuid
 from celery.result import AsyncResult, ResultSet
 from collections import deque
 
+
 @task()
 def add(x, y):
     return x + y
@@ -30,20 +31,22 @@ def add(x, y):
 
 @task()
 def make_request(id, url):
-    print('GET %r' % (url, ))
+    print('GET {0!r}'.format(url))
     return url
 
 
 @task()
 def B_callback(urls, id):
-    print('batch %s done' % (id, ))
+    print('batch {0} done'.format(id))
     return urls
 
 
 @task()
 def B(id):
-    return chord(make_request.s(id, '%s %r' % (id, i, ))
-                    for i in xrange(10))(B_callback.s(id))
+    return chord(
+        make_request.s(id, '{0} {1!r}'.format(id, i))
+        for i in range(10)
+    )(B_callback.s(id))
 
 
 @task()
@@ -71,12 +74,12 @@ def joinall(R, timeout=None, propagate=True):
 
 
 @task()
-def unlock_graph(result, callback, interval=1, propagate=False,
-        max_retries=None):
+def unlock_graph(result, callback,
+                 interval=1, propagate=False, max_retries=None):
     if result.ready():
         second_level_res = result.get()
         if second_level_res.ready():
-            subtask(callback).delay(list(joinall(
+            signature(callback).delay(list(joinall(
                 second_level_res, propagate=propagate)))
     else:
         unlock_graph.retry(countdown=interval, max_retries=max_retries)
@@ -84,7 +87,7 @@ def unlock_graph(result, callback, interval=1, propagate=False,
 
 @task()
 def A_callback(res):
-    print('Everything is done: %r' % (res, ))
+    print('Everything is done: {0!r}'.format(res))
     return res
 
 
